local tec = TeamEquipCompare;
tec.options = {
    name = "Team Equip Compare v"..tec.version,
    type = "group",
    args = {
		config = {
			order = 1;
			guiHidden = true;
            type = "execute",
			name = "Config",
            desc = "Open Ace3 Config GUI",
            func = function(...) InterfaceOptionsFrame_OpenToCategory("Team Equip Compare") end,
		},
		notify = {
			order = 2,
			cmdHidden = true;
            type = "toggle",
			name = "Show Notification Messages",
            desc = "Check to display TeamEquipCompare update messages in the general chat window.  Uncheck to disable notification messages.",
            get = function(...) return tec.db.global.showNotificationMsgs end,
            set = function(t, val) tec.db.global.showNotificationMsgs = val end,
			width = "full",
		},
		ctrl = {
			order = 3,
			cmdHidden = true;
            type = "toggle",
			name = "Ctrl-Key Tooltip",
            desc = "Check to require the the Ctrl-Key be pressed to show the TeamEquipCompare tooltip lines.  Uncheck to always show the TeamEquipCompare tooltip lines.",
            get = function(...) return tec.db.global.requireCtrlKey end,
            set = function(t, val) tec.db.global.requireCtrlKey = val end,
			width = "full",
		},
		unusable = {
			order = 4,
			cmdHidden = true;
            type = "toggle",
			name = "Hide stat comparison if ITEM requirements are not met",
            desc = "Check to hide the stat comparison tooltip lines when the item is unusable by that team member.  Uncheck to show all stat comparisons regardless of item requirements.",
            get = function(...) return tec.db.global.hideUnusable end,
            set = function(t, val) tec.db.global.hideUnusable = val end,
			width = "full",
		},
		levelCheck = {
			order = 5,
			cmdHidden = true;
            type = "toggle",
			name = "Hide stat comparison if LEVEL requirements are not met",
            desc = "Check to hide the stat comparison tooltip lines if the team member has not met the level requirements.  Uncheck to show all stat comparisons regardless of level requirements.",
			disabled = function() return not tec.db.global.hideUnusable end,
            get = function(...) return tec.db.global.levelCheck end,
            set = function(t, val) tec.db.global.levelCheck = val end,
			width = "full",
		},
		debug = {
			order = 6,
			cmdHidden = true;
            type = "toggle",
			name = "Show Debug Messages",
            desc = "Check to display TeamEquipCompare debugging messages in the general chat window [Not Recommended].  Uncheck to disable notification messages.",
            get = function(...) return tec.db.global.showDebugMsgs end,
            set = function(t, val) tec.db.global.showDebugMsgs = val end,
			width = "full",
			confirm = function(...)
				if (not tec.db.global.showDebugMsgs) then
					return "This will generate A LOT of chat text.  Are you sure you want to show debugging messages?";
				else
					return false;
				end
			end,
		},
		money = {
			order = 7,
			cmdHidden = true;
            type = "toggle",
			name = "Track Team Money",
            desc = "Check to track money per team member.  Uncheck to disable money data transfer.  Use '/tec team' to see values.",
            get = function(...) return tec.db.global.trackMoney end,
            set = function(t, val) tec.db.global.trackMoney = val end,
			width = "full",
		},
		moneytrigger = {
			order = 8,
			cmdHidden = true;
			type = "range",
			name = "Money Trigger Amount",
			desc = "The change in player money (in gold) before a data update is pushed to the rest of the team.  A value of 0 means all updates will be pushed.",
			min = 0,
			max = 25,
			step = 0.5,
			bigStep = 1,
			disabled = function() return not tec.db.global.trackMoney end,
			get = function(t) return tec.db.global.moneyThreshhold end,
			set = function(t, val) tec.db.global.moneyThreshhold = val end,
		},
        sync = {
			order = 9,
            type = "execute",
			name = "Force Data Sync",
            desc = "Synchronize equipment data with all party members",
            func = function(...) TEC_RequestPartyData() end,
			width = "full",
        },
		team = {
			order = 10;
			guiHidden = true;
            type = "execute",
			name = "Team",
            desc = "List party members - <name>: ",
            func = function(...) TEC_PrintTeam() end,
		},
    },
};